public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] portage r10774 - main/trunk/pym/_emerge
@ 2008-06-24 22:55 Zac Medico (zmedico)
  0 siblings, 0 replies; only message in thread
From: Zac Medico (zmedico) @ 2008-06-24 22:55 UTC (permalink / raw
  To: gentoo-commits

Author: zmedico
Date: 2008-06-24 22:55:17 +0000 (Tue, 24 Jun 2008)
New Revision: 10774

Modified:
   main/trunk/pym/_emerge/__init__.py
Log:
Fix spelling of depgraph._complete_threshold.


Modified: main/trunk/pym/_emerge/__init__.py
===================================================================
--- main/trunk/pym/_emerge/__init__.py	2008-06-24 22:53:25 UTC (rev 10773)
+++ main/trunk/pym/_emerge/__init__.py	2008-06-24 22:55:17 UTC (rev 10774)
@@ -1885,7 +1885,7 @@
 	# enable "complete" mode since any performance difference is
 	# not as likely to be noticed by the user after this much time
 	# has passed.
-	_complete_thresold = 20
+	_complete_threshold = 20
 
 	def __init__(self, settings, trees, myopts, myparams, spinner):
 		self._creation_time = time.time()
@@ -3386,14 +3386,14 @@
 
 		Since this method can consume enough time to disturb users, it is
 		currently only enabled by the --complete-graph option, or when
 		dep calculation time exceeds self._complete_thresold.
 		"""
 		if "--buildpkgonly" in self.myopts or \
 			"recurse" not in self.myparams:
 			return 1
 
 		if "complete" not in self.myparams:
-			if time.time() - self._creation_time > self._complete_thresold:
+			if time.time() - self._creation_time > self._complete_threshold:
 				self.myparams.add("complete")
 			else:
 				# Skip this to avoid consuming enough time to disturb users.
@@ -3386,14 +3386,14 @@
 		Since this method can consume enough time to disturb users, it is
 		currently only enabled by the --complete-graph option, or when
-		dep calculation time exceeds self._complete_thresold.
+		dep calculation time exceeds self._complete_threshold.
 		"""
 		if "--buildpkgonly" in self.myopts or \

-- 
gentoo-commits@lists.gentoo.org mailing list



^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2008-06-24 22:55 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-06-24 22:55 [gentoo-commits] portage r10774 - main/trunk/pym/_emerge Zac Medico (zmedico)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox